<?php

namespace Bixo\Company\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Bixo\Company\Http\Requests\DivisionsRequest;
use Bixo\Company\Interfaces\DivisionsRepositoryInterface;
use Bixo\Company\Models\Divisions;
use Bixo\Company\Forms\Divisions as Form;

/**
 * APIController  class for divisions.
 */
class DivisionsAPIController extends BaseController
{

    /**
     * Initialize divisions resource controller.
     *
     * @param type DivisionsRepositoryInterface $divisions
     *
     * @return null
     */
    public function __construct(DivisionsRepositoryInterface $divisions)
    {
        parent::__construct();
        $this->repository = $divisions;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Bixo\Company\Repositories\Criteria\DivisionsResourceCriteria::class);
    }

    /**
     * Display a list of divisions.
     *
     * @return Response
     */
    public function index(DivisionsRequest $request)
    {
        return $this->repository
            ->setPresenter(\Bixo\Company\Repositories\Presenter\DivisionsPresenter::class)
            ->paginate();
    }

    /**
     * Display divisions.
     *
     * @param Request $request
     * @param Model   $divisions
     *
     * @return Response
     */
    public function show(DivisionsRequest $request, Divisions $divisions)
    {
        return $divisions->setPresenter(\Bixo\Company\Repositories\Presenter\DivisionsListPresenter::class);
        ;
    }

    /**
     * Create new divisions.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(DivisionsRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('company::divisions.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('company/divisions/' . $divisions->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('company/divisions');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the divisions.
     *
     * @param Request $request
     * @param Model   $divisions
     *
     * @return Response
     */
    public function update(DivisionsRequest $request, Divisions $divisions)
    {
        try {
            $data = $request->all();

            $divisions->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('company::divisions.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('company/divisions/' . $divisions->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('company/divisions/' . $divisions->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the divisions.
     *
     * @param Model   $divisions
     *
     * @return Response
     */
    public function destroy(DivisionsRequest $request, Divisions $divisions)
    {
        try {
            $divisions->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('company::divisions.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('company/divisions/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('company/divisions/' . $divisions->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
