<?php

namespace Bixo\Company\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Company\Models\Companies;

class CompaniesPolicy
{

    /**
     * Determine if the given user can view the companies.
     *
     * @param UserPolicy $user
     * @param Companies $companies
     *
     * @return bool
     */
    public function view(UserPolicy $user, Companies $companies)
    {
        if ($user->canDo('company.companies.view') && $user->isAdmin()) {
            return true;
        }

        return $companies->user_id == user_id() && $companies->user_type == user_type();
    }

    /**
     * Determine if the given user can create a companies.
     *
     * @param UserPolicy $user
     * @param Companies $companies
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('company.companies.create');
    }

    /**
     * Determine if the given user can update the given companies.
     *
     * @param UserPolicy $user
     * @param Companies $companies
     *
     * @return bool
     */
    public function update(UserPolicy $user, Companies $companies)
    {
        if ($user->canDo('company.companies.edit') && $user->isAdmin()) {
            return true;
        }

        return $companies->user_id == user_id() && $companies->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given companies.
     *
     * @param UserPolicy $user
     * @param Companies $companies
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Companies $companies)
    {
        return $companies->user_id == user_id() && $companies->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given companies.
     *
     * @param UserPolicy $user
     * @param Companies $companies
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Companies $companies)
    {
        if ($user->canDo('company.companies.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given companies.
     *
     * @param UserPolicy $user
     * @param Companies $companies
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Companies $companies)
    {
        if ($user->canDo('company.companies.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
