<?php

namespace Bixo\Company\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Company\Models\Divisions;

class DivisionsPolicy
{

    /**
     * Determine if the given user can view the divisions.
     *
     * @param UserPolicy $user
     * @param Divisions $divisions
     *
     * @return bool
     */
    public function view(UserPolicy $user, Divisions $divisions)
    {
        if ($user->canDo('company.divisions.view') && $user->isAdmin()) {
            return true;
        }

        return $divisions->user_id == user_id() && $divisions->user_type == user_type();
    }

    /**
     * Determine if the given user can create a divisions.
     *
     * @param UserPolicy $user
     * @param Divisions $divisions
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('company.divisions.create');
    }

    /**
     * Determine if the given user can update the given divisions.
     *
     * @param UserPolicy $user
     * @param Divisions $divisions
     *
     * @return bool
     */
    public function update(UserPolicy $user, Divisions $divisions)
    {
        if ($user->canDo('company.divisions.edit') && $user->isAdmin()) {
            return true;
        }

        return $divisions->user_id == user_id() && $divisions->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given divisions.
     *
     * @param UserPolicy $user
     * @param Divisions $divisions
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Divisions $divisions)
    {
        return $divisions->user_id == user_id() && $divisions->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given divisions.
     *
     * @param UserPolicy $user
     * @param Divisions $divisions
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Divisions $divisions)
    {
        if ($user->canDo('company.divisions.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given divisions.
     *
     * @param UserPolicy $user
     * @param Divisions $divisions
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Divisions $divisions)
    {
        if ($user->canDo('company.divisions.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
