<?php

namespace Bixo\Company\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Company\Models\Offices;

class OfficesPolicy
{

    /**
     * Determine if the given user can view the offices.
     *
     * @param UserPolicy $user
     * @param Offices $offices
     *
     * @return bool
     */
    public function view(UserPolicy $user, Offices $offices)
    {
        if ($user->canDo('company.offices.view') && $user->isAdmin()) {
            return true;
        }

        return $offices->user_id == user_id() && $offices->user_type == user_type();
    }

    /**
     * Determine if the given user can create a offices.
     *
     * @param UserPolicy $user
     * @param Offices $offices
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('company.offices.create');
    }

    /**
     * Determine if the given user can update the given offices.
     *
     * @param UserPolicy $user
     * @param Offices $offices
     *
     * @return bool
     */
    public function update(UserPolicy $user, Offices $offices)
    {
        if ($user->canDo('company.offices.edit') && $user->isAdmin()) {
            return true;
        }

        return $offices->user_id == user_id() && $offices->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given offices.
     *
     * @param UserPolicy $user
     * @param Offices $offices
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Offices $offices)
    {
        return $offices->user_id == user_id() && $offices->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given offices.
     *
     * @param UserPolicy $user
     * @param Offices $offices
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Offices $offices)
    {
        if ($user->canDo('company.offices.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given offices.
     *
     * @param UserPolicy $user
     * @param Offices $offices
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Offices $offices)
    {
        if ($user->canDo('company.offices.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
