<?php

namespace Bixo\Company\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Company\Models\Subdivisions;

class SubdivisionsPolicy
{

    /**
     * Determine if the given user can view the subdivisions.
     *
     * @param UserPolicy $user
     * @param Subdivisions $subdivisions
     *
     * @return bool
     */
    public function view(UserPolicy $user, Subdivisions $subdivisions)
    {
        if ($user->canDo('company.subdivisions.view') && $user->isAdmin()) {
            return true;
        }

        return $subdivisions->user_id == user_id() && $subdivisions->user_type == user_type();
    }

    /**
     * Determine if the given user can create a subdivisions.
     *
     * @param UserPolicy $user
     * @param Subdivisions $subdivisions
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('company.subdivisions.create');
    }

    /**
     * Determine if the given user can update the given subdivisions.
     *
     * @param UserPolicy $user
     * @param Subdivisions $subdivisions
     *
     * @return bool
     */
    public function update(UserPolicy $user, Subdivisions $subdivisions)
    {
        if ($user->canDo('company.subdivisions.edit') && $user->isAdmin()) {
            return true;
        }

        return $subdivisions->user_id == user_id() && $subdivisions->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given subdivisions.
     *
     * @param UserPolicy $user
     * @param Subdivisions $subdivisions
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Subdivisions $subdivisions)
    {
        return $subdivisions->user_id == user_id() && $subdivisions->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given subdivisions.
     *
     * @param UserPolicy $user
     * @param Subdivisions $subdivisions
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Subdivisions $subdivisions)
    {
        if ($user->canDo('company.subdivisions.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given subdivisions.
     *
     * @param UserPolicy $user
     * @param Subdivisions $subdivisions
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Subdivisions $subdivisions)
    {
        if ($user->canDo('company.subdivisions.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
